pub fn should_compact<M, E>(
messages: &[M],
config: &CompactionConfig,
estimator: &E,
) -> boolExpand description
Return true when compaction should run for this transcript.
pub fn should_compact<M, E>(
messages: &[M],
config: &CompactionConfig,
estimator: &E,
) -> boolReturn true when compaction should run for this transcript.